import os

def getFileList(path, type=()):
    '''
    :param path: files path
    :param type: filter types
    :return: file list
    '''
    Filelist = []
    for home, dirs, files in os.walk(path):
        for filename in files:
            if len([]) == 0:
                Filelist.append(os.path.join(home, filename))
            else:
                if filename.endswith(type):
                    if os.path.getsize(os.path.join(home, filename)) == 0:
                        continue
                    Filelist.append(os.path.join(home, filename))
    return Filelist


from distutils.core import setup
from setuptools import find_packages

setup(name='ahbcwin',  # 包名
      version='20210322.0.0.001',  # 版本号
      description='',
      long_description='',
      author='',
      author_email='',
      url='',
      license='',
      install_requires=[],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.5',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.2',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Topic :: Utilities'
      ],
      keywords='',
      packages=find_packages('src'),  # 必填，就是包的代码主目录
      package_dir={'': 'src'},  # 必填
      include_package_data=True,
      )
# !/usr/bin/env python
